@@ -1,10 +1,10 @@
 ##############################################################################
 # MDTraj: A Python Library for Loading, Saving, and Manipulating
 #         Molecular Dynamics Trajectories.
-# Copyright 2012-2022 Stanford University and the Authors
+# Copyright 2012-2024 Stanford University and the Authors
 #
 # Authors: Robert McGibbon
-# Contributors: Kyle A. Beauchamp, TJ Lane, Joshua Adelman, Lee-Ping Wang, Jason Swails
+# Contributors: Sukrit Singh, Kyle A. Beauchamp, TJ Lane, Joshua Adelman, Lee-Ping Wang, Jason Swails
 #
 # MDTraj is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as
@@ -1474,7 +1474,7 @@ class Trajectory:
         # run the saver, and return whatever output it gives
         return saver(filename, **kwargs)
 
-    def save_hdf5(self, filename, force_overwrite=True):
+    def save_hdf5(self, filename, mode="w", force_overwrite=True):
         """Save trajectory to MDTraj HDF5 format
 
         Parameters
@@ -1483,8 +1483,15 @@ class Trajectory:
             filesystem path in which to save the trajectory
         force_overwrite : bool, default=True
             Overwrite anything that exists at filename, if its already there
+        mode : str, default='w'
+            The mode in which to save the file. 'w' will overwrite any existing
+            file, 'a' will append to an existing file.
         """
-        with HDF5TrajectoryFile(filename, "w", force_overwrite=force_overwrite) as f:
+        # check if savemode is valid (only "w" or "a" are allowed)
+        if mode not in ["w", "a"]:
+            raise ValueError("savemode must be either 'w' or 'a'")
+        
+        with HDF5TrajectoryFile(filename, mode, force_overwrite=force_overwrite) as f:
             f.write(
                 coordinates=in_units_of(
                     self.xyz,
@@ -1538,7 +1545,7 @@ class Trajectory:
                 types=[a.name for a in self.top.atoms],
             )
 
-    def save_pdb(self, filename, force_overwrite=True, bfactors=None):
+    def save_pdb(self, filename, force_overwrite=True, bfactors=None, ter=True):
         """Save trajectory to RCSB PDB format
 
         Parameters
@@ -1551,6 +1558,9 @@ class Trajectory:
             Save bfactors with pdb file. If the array is two dimensional it should
             contain a bfactor for each atom in each frame of the trajectory.
             Otherwise, the same bfactor will be saved in each frame.
+        ter : bool, default=True
+            Include TER lines in pdb to indicate end of a chain of residues. This is useful
+            if you need to keep atom numbers consistent.
         """
         self._check_valid_unitcell()
 
@@ -1592,6 +1602,7 @@ class Trajectory:
                             f.distance_unit,
                         ),
                         unitcell_angles=self.unitcell_angles[i],
+                        ter=ter,
                     )
                 else:
                     f.write(
@@ -1603,6 +1614,7 @@ class Trajectory:
                         self.topology,
                         modelIndex=i,
                         bfactors=bfactors[i],
+                        ter=ter,
                     )
 
     def save_xtc(self, filename, force_overwrite=True):
