@@ -34,7 +34,7 @@ from datetime import datetime
 
 import numpy as np
 
-from mdtraj import version
+import mdtraj
 from mdtraj.formats.registry import FormatRegistry
 from mdtraj.utils import cast_indices, ensure_type, import_, in_units_of
 
@@ -158,8 +158,6 @@ class NetCDFTrajectoryFile:
             # for scipy.io.netcdf_file is "version=2"
             input_args = {"version": 2}
 
-        netcdf = import_("scipy.io").netcdf_file  # noqa: F841
-
         if mode not in ["r", "w"]:
             raise ValueError("mode must be one of ['r', 'w']")
 
@@ -547,7 +545,7 @@ class NetCDFTrajectoryFile:
         )
         setattr(self._handle, "application", "Omnia")
         setattr(self._handle, "program", "MDTraj")
-        setattr(self._handle, "programVersion", version.short_version)
+        setattr(self._handle, "programVersion", mdtraj.__version__)
         setattr(self._handle, "Conventions", "AMBER")
         setattr(self._handle, "ConventionVersion", "1.0")
 
