@@ -183,6 +183,7 @@ def shrake_rupley(
     mode="atom",
     change_radii=None,
     get_mapping=False,
+    atom_indices=None
 ):
     """Compute the solvent accessible surface area of each atom or residue in each simulation frame.
 
@@ -207,6 +208,15 @@ def shrake_rupley(
         Instead of returning only the areas, also return the indices of the
         atoms or the residue-to-atom mapping. If True, will return a tuple
         that contains the areas and the mapping (np.array, shape=(n_atoms)).
+    atom_indices : iterable, optional
+        Selection of atoms indices for which the SASA will be computed.
+        Default is all atoms, but a sub-selection of atoms can be
+        passed here. This selection doesn't affect what
+        atoms are considered accessibility blockers, it only affects
+        for what atoms the SASA is computed. E.g. you can pass a lipid-embedded
+        protein (s.t. the lipids are considered blockers) but only compute
+        SASA for the protein using atom_selection = traj.top.select("protein").
+        The excluded atoms/residues get a SASA value -1.
 
     Returns
     -------
@@ -272,9 +282,16 @@ def shrake_rupley(
                 "residues must have contiguous integer indices " "starting from zero",
             )
     else:
-        raise ValueError(
-            'mode must be one of "residue", "atom". "%s" supplied' % mode,
-        )
+        raise ValueError('mode must be one of "residue", "atom". "%s" supplied' %
+                         mode)
+
+    if atom_indices is None:
+        atom_selection_mask = np.ones(traj.n_atoms, dtype=np.int32)
+        out = np.zeros((xyz.shape[0], dim1), dtype=np.float32)
+    else:
+        atom_selection_mask = np.array([[1 if ii in atom_indices else 0][0] for ii in range(traj.n_atoms)], dtype=np.int32)
+        out = np.full((xyz.shape[0], dim1), -1, dtype=np.float32)
+        out[:,atom_mapping[atom_indices]]=0
 
     modified_radii = {}
     if change_radii is not None:
@@ -284,14 +301,13 @@ def shrake_rupley(
         for k, v in change_radii.items():
             modified_radii[k] = v
 
-    out = np.zeros((xyz.shape[0], dim1), dtype=np.float32)
     if bool(modified_radii):
         atom_radii = [modified_radii[atom.element.symbol] for atom in traj.topology.atoms]
     else:
         atom_radii = [_ATOMIC_RADII[atom.element.symbol] for atom in traj.topology.atoms]
     radii = np.array(atom_radii, np.float32) + probe_radius
 
-    _geometry._sasa(xyz, radii, int(n_sphere_points), atom_mapping, out)
+    _geometry._sasa(xyz, radii, int(n_sphere_points), atom_mapping, atom_selection_mask, out)
 
     if get_mapping is True:
         return out, atom_mapping
