@@ -1,4 +1,5 @@
 import itertools
+import pytest
 
 import numpy as np
 
@@ -45,3 +46,11 @@ def test_generator():
     a = md.compute_angles(ptraj, triplets)
     b = md.compute_angles(ptraj, triplets2)
     eq(a, b)
+
+@pytest.mark.parametrize("optimize", [True, False])
+def test_angle_180(get_fn, optimize):
+    # Test that linear coordinates yield 180 degrees, not "nan"
+    a = md.load(get_fn('mol.gro'))
+    b = md.compute_angles(a, [[0, 1, 2]], opt=optimize)
+    assert not np.isnan(b[0][0])
+    assert pytest.approx(b[[0]], np.pi*1e-4) == np.pi
